@@ -14,8 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
- *
- * $Id: dice.c,v 1.108 2024/02/19 21:09:02 plm Exp $
  */
 
 #include "config.h"
@@ -23,13 +21,20 @@
 #include "randomorg.h"
 
 #include <fcntl.h>
+
 #if defined(HAVE_LIBGMP)
-#ifdef sun
+/*
+ * The condition is not entirely accurate, gmp.h is still in
+ * the gmp subdirectory in Solaris 11.1 but no longer in 11.4.
+ * Make it work in the up to date case.
+ */
+#ifdef __SunOS_5_10
 #include <gmp/gmp.h>
 #else
 #include <gmp.h>
 #endif
 #endif
+
 #include <glib.h>
 #if HAVE_UNISTD_H
 #include <unistd.h>
@@ -379,8 +384,8 @@ PrintRNGSeedMP(mpz_t n)
 
     char *pch;
     pch = mpz_get_str(NULL, 10, n);
-    g_print(_("The current seed is"));
-    g_print(" %s\n", pch);
+    g_print(_("The current seed is %s"), pch);
+    g_print("\n");
     free(pch);
 
 }
@@ -391,8 +396,8 @@ static void
 PrintRNGSeedNormal(unsigned int n)
 {
 
-    g_print(_("The current seed is"));
-    g_print(" %u.\n", n);
+    g_print(_("The current seed is %u."), n);
+    g_print("\n");
 
 }
 #endif                          /* HAVE_LIBGMP */
@@ -406,17 +411,16 @@ PrintRNGSeed(const rng rngx, rngcontext * rngctx)
     case RNG_BBS:
 #if defined(HAVE_LIBGMP)
         {
-            char *pch;
+            char *pch0, *pch1;
 
-            pch = mpz_get_str(NULL, 10, rngctx->zSeed);
-            g_print(_("The current seed is"));
-            g_print(" %s, ", pch);
-            free(pch);
+            pch0 = mpz_get_str(NULL, 10, rngctx->zSeed);
+            pch1 = mpz_get_str(NULL, 10, rngctx->zModulus);
 
-            pch = mpz_get_str(NULL, 10, rngctx->zModulus);
-            g_print(_("and the modulus is %s."), pch);
+            g_print(_("The current seed is %s, and the modulus is %s."), pch0, pch1);
             g_print("\n");
-            free(pch);
+
+            free(pch0);
+            free(pch1);
 
             return;
         }
@@ -425,8 +429,8 @@ PrintRNGSeed(const rng rngx, rngcontext * rngctx)
 #endif
 
     case RNG_MD5:
-        g_print(_("The current seed is"));
-        g_print(" %u.\n", rngctx->nMD5);
+        g_print(_("The current seed is %u."), rngctx->nMD5);
+        g_print("\n");
         return;
 
     case RNG_FILE:
