@@ -15,7 +15,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  *
- * $Id: show.c,v 1.313 2024/02/18 16:30:31 plm Exp $
+ * $Id: show.c,v 1.312 2024/02/14 07:38:01 plm Exp $
  */
 
 #include "config.h"
@@ -644,7 +644,7 @@ CommandShowCrawford(char *UNUSED(sz))
 {
 
     if (ms.nMatchTo > 0)
-        outputl(ms.fCrawford ? _("This game is the Crawford game.") : _("This game is not the Crawford game"));
+        outputl(ms.fCrawford ? _("This game is the Crawford game.") : _("This game is not the Crawford game."));
     else if (!ms.nMatchTo)
         outputl(_("Crawford rule is not used in money sessions."));
     else
